################################################
# PANELS
################################################

# Note: Uncommenting means to delete the "#" at the beginning of a line. Commenting out means to add a "#" at the beginning of a line. The "#" tells the theme wether to ignore the line or not.

style "theme-panel"
{
# The following line adds gradient panel backgrounds. Delete or comment it out to have regular, flat gnome-panels.
bg_pixmap[NORMAL]				= "/Panels/panel-bg-dark.png" # Dark gradient panel.


fg[ACTIVE]   = lighter (@selected_bg_color) # Text color of active panel button.
}

# Panels. Do not change.
widget "*PanelWidget*"		style "theme-panel"
widget "*PanelApplet*"		style "theme-panel"
widget "*fast-user-switch*"	style "theme-panel"
widget "*CPUFreq*Applet*"	style "theme-panel"
widget "*indicator-applet*"	style "theme-panel"
class "PanelApp*"		style "theme-panel"
class "PanelToplevel*"		style "theme-panel"
widget_class "*PanelToplevel*"	style "theme-panel"
widget_class "*Mail*"		style "theme-panel"
#class "*Panel*"		style "theme-panel" # Disabled to fix bug.
widget_class "*notif*"		style "theme-panel"
widget_class "*Notif*"		style "theme-panel"
widget_class "*Tray*"		style "theme-panel" 
widget_class "*tray*"		style "theme-panel"
widget_class "*Applet*Tomboy*"	style "theme-panel"
widget_class "*Applet*Netstatus*"	style "theme-panel"

# XFCE panel theming: (non-gradient), only active text.
widget "*Xfce*Panel*"		style "theme-panel"
class "*Xfce*Panel*"		style "theme-panel"
